@@ -1,8 +1,8 @@
 /*
 **  OSSP var -- Variable Expansion
-**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2004 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2004 Cable & Wireless (http://www.cw.com/)
+**  Copyright (c) 2001-2005 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2005 The OSSP Project (http://www.ossp.org/)
+**  Copyright (c) 2001-2005 Cable & Wireless (http://www.cw.com/)
 **
 **  This file is part of OSSP var, a variable expansion
 **  library which can be found at http://www.ossp.org/pkg/lib/var/.
@@ -102,9 +102,9 @@ static var_rc_t lookup_cb(
                        && strncmp(varname, vars[i + counter].name, name_len) == 0)
                     counter++;
                 if (counter == 1)
-                    sprintf(buf, "%d", length);
+                    sprintf(buf, "%d", (int)length);
                 else
-                    sprintf(buf, "%d", counter);
+                    sprintf(buf, "%d", (int)counter);
                 *data = buf;
                 *data_len = strlen(buf);
                 *buffer_size = 0;
